Package: catregs
Type: Package
Title: Post-Estimation Functions for Generalized Linear Mixed Models
Version: 1.3
Authors@R: c(person("David", "Melamed", role = c("aut", "cre"), email = "dmmelamed@gmail.com", comment = c(ORCID = "0000-0002-8821-7698")))
Description: Several functions for working with mixed effects regression models for limited dependent variables. The functions facilitate post-estimation of model predictions or margins, and comparisons between model predictions for assessing or probing moderation. Additional helper functions facilitate model comparisons and implements simulation-based inference for model predictions of alternative-specific outcome models. See also, Melamed and Doan (2024, ISBN: 978-1032509518). 
Depends: R (>= 3.5.0)
License: GPL-2 | GPL-3
Encoding: UTF-8
LazyData: true
Imports: methods
Suggests: tidyverse, ggplot2, MASS, emmeans, pscl, nnet,
        marginaleffects, ggpubr, knitr, rmarkdown, Epi, dplyr, ordinal,
        nlme, lme4
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-12-18 22:56:42 UTC; melamed.9
Author: David Melamed [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8821-7698>)
Maintainer: David Melamed <dmmelamed@gmail.com>
Repository: CRAN
Date/Publication: 2025-12-18 23:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 13:59:22 UTC; unix
