---
title: "list.coef"
output: rmarkdown::html_vignette
description: >
  This vignette explains the rationale and implementation for the list.coef function.
vignette: >
  %\VignetteIndexEntry{list.coef}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

Regression models for limited dependent variables are interpreted in several different ways. The estimated coefficients are often transformed before being interpreted, for example. Exponentiating logistic or count regression coefficients is common, as is converting the coefficient into percent change. The list.coef function transforms model coefficients into these additional quantities. It also reports confidence intervals for exponentiated coefficients. Users may specify the \# of decimal places to report and the alpha level. For example:

```{r}
library(catregs)
data("Mize19AH")
m1 <- glm(alcB ~woman*parrole + age + race2 + race3 + race4 + income + ed1 + ed2 + ed3 + ed4,family="binomial",data=Mize19AH)
list.coef(m1)
```

In the above, b refers to the original model coefficient, S.E. to the estimated model coefficient's standard error, Z is the z-statistic (b/se(b)), LL.CI is the lower limit of the confidence interval around the model coefficient, UL.CI is the upper limit of the confidence interval around the model coefficient, p-val is the p-value associated with the z-statistic, exp.b is the exponentiated model coefficient, LL.CI.for.exp.b is the lower limit of the confidence interval around the exponentiated model coefficient, UL.CI.for.exp.b is the upper limit of the confidence interval around the exponentiated model coefficient, Percent is the % change interpretation of the coefficient, i.e., 100\*(1-(exp(b))), and CI is the amount of confidence in the confidence interval.
